@@ -1,4 +1,4 @@
-package Pcore::PgSQL v0.21.4;
+package Pcore::PgSQL v0.21.5;
 
 use Pcore -dist, -class;
 
@@ -53,6 +53,13 @@ sub run ( $self ) {
         );
     }
 
+    # timescaledb init
+    if ( $ENV{TIMESCALEDB} ) {
+        my $conf = P->file->read_bin("$db_dir/postgresql.conf");
+
+        P->file->append_text( "$db_dir/postgresql.conf", qq[\nshared_preload_libraries = 'timescaledb'\n] ) if $conf->$* !~ /shared_preload_libraries\s*=\s*'timescaledb'/sm;
+    }
+
     # create and prepare unix socket dir
     P->file->mkdir('/var/run/postgresql/') if !-d '/var/run/postgresql';
     chown $uid, $uid, '/var/run/postgresql/' or die;
